## Wav2vec Bahasa

## Table of contents
  * [Objective](#objective)
  * [Acknowledgement](#acknowledgement)

## Objective

1. Provide wav2vec for bahasa, bahasa rojak and manglish speeches.

## Acknowledgement

Thanks to [Im Big](https://www.facebook.com/imbigofficial/), [LigBlou](https://www.facebook.com/ligblou), [Mesolitica](https://mesolitica.com/) and [KeyReply](https://www.keyreply.com/) for sponsoring AWS, Google and GPU clouds to train BERT for Bahasa.